.tdbmd-home .tdbmd-banner {
    background: var(--background-alt-blue-france);
}
.tdbmd-home .tdbmd-tile-container .fr-tile {
    position: relative;
    top: 3rem;
}
.tdbmd-home .tdbmd-pros__img {
    max-width: 100%;
    position: relative;
    float: right;
    bottom: 0;
    right: 0;
}
@media (min-width: 1700px) {
    .tdbmd-home .tdbmd-pros__img {
        right: -15rem;
    }
}
.tdbmd-home .tdbmd-pros__item-icon > svg {
    color: var(--background-action-high-blue-france);
    margin: 1rem 0;
    vertical-align: bottom;
    width: 2.5rem;
}

@media (min-width: 576px) {
    .tdbmd-home .tdbmd-pros__item-icon > svg {
        margin: initial;
        width: 2rem;
    }
}
.tdbmd-home .tdbmd-pros .clear {
    clear: both;
}
.tdbmd-home .tdbmd-target-profiles {
    background: var(--background-alt-blue-france);
}
.tdbmd-home .tdbmd-target-profiles li {
    list-style-type: none;
}
.tdbmd-home .tdbmd-target-profiles .fr-card__desc {
    display: inline-block;
    min-height: 3rem;
}
@media (min-width: 992px) {
    .tdbmd-home .tdbmd-target-profiles .fr-card__desc {
        min-height: 4rem;
    }
}
@media (min-width: 1248px) {
    .tdbmd-home .tdbmd-target-profiles .fr-card__desc {
        min-height: 7rem;
    }
}
.tdbmd-lexicon__term dfn {
    font-weight: 700;
    font-style: normal;
}
.tdbmd-lexicon__term:not(:first-child) {
    margin-top: 1rem;
}
.tdbmd-lexicon__def {
    padding-left: 0;
}
@media (min-width: 768px) {
    .tdbmd-lexicon {
        display: flex;
        flex-wrap: wrap;
    }
    .tdbmd-lexicon__term {
        width: 20%;
    }
    .tdbmd-lexicon__term:nth-child(n + 3) {
        margin-top: 2rem;
    }
    .tdbmd-lexicon__def {
        width: 80%;
        padding-left: 2rem;
        box-sizing: border-box;
    }
    .tdbmd-lexicon__def:nth-child(n + 3) {
        margin-top: 2rem;
    }
}
.tdbmd-content {
    position: relative;
}
.tdbmd-thematics {
    box-sizing: border-box;
}
.tdbmd-thematics__content {
    box-sizing: border-box;
    border-left: 1px solid var(--border-default-grey);
}
.tdbmd-thematics__btns {
    display: flex;
    flex-direction: column;
    gap: 1rem;
    margin: 0 1rem;
}
@media (min-width: 575px) {
    .tdbmd-thematics__btns {
        flex-direction: row;
        justify-content: flex-end;
    }
}
.tdbmd-thematics .fr-sidemenu__inner {
    box-shadow: none;
}
.tdbmd-thematics .fr-sidemenu {
    padding-right: 0;
    margin: 0;
}
.tdbmd-thematics .subtheme:nth-child(even) {
    background: var(--background-alt-blue-france);
}
.tdbmd-thematics .subtheme:nth-child(odd) {
    background: white;
}
.tdbmd-thematics .subtheme h2 {
    padding: 1rem 0;
    margin-bottom: 0;
}
.tdbmd-slide-panel .tdbmd-territory-tabs h2 {
    margin-left: 0;
}
.tdbmd-slide-panel .tdbmd-territory-tabs .autocomplete-input {
    margin-bottom: 0;
}
.tdbmbd-tabpanel-panel {
    padding-bottom: 64px;
}
.tdbmd-slide-panel .tdbmd-combobox-suggestions {
    max-height: 200px;
    overflow-y: scroll;
    width: 100%;
    margin: 0;
    padding: 0;
    list-style-type: none;
    box-sizing: border-box;
    margin-bottom: 2rem;
    margin-top: 2px;
}
.tdbmd-slide-panel .tdbmd-combobox-suggestions--opened {
    border-bottom: 2px solid var(--background-action-high-blue-france);
    border-left: 2px solid var(--background-action-high-blue-france);
    border-right: 2px solid var(--background-action-high-blue-france);
}
.tdbmd-combobox-suggestions li {
    padding: 0.25rem 1rem;
    box-sizing: border-box;
}
.tdbmd-combobox-suggestions li:hover {
    background-color: var(--background-alt-blue-france);
    cursor: pointer;
}
.tdbmd-mesh {
    position: relative;
    width: 100%;
}
.tdbmd-mesh ul {
    position: absolute;
    z-index: 100;
    width: 100%;
}
@media (min-width: 575px) {
    .tdbmd-mesh {
        width: 200px;
    }
}
.tdbmd-mesh__list {
    list-style-type: none;
    padding: 0;
    margin: 0;
    background: white;
    box-shadow: -1px 1px 5px 1px var(--border-default-grey);
}
.tdbmd-mesh__list-item {
    margin: 0;
    padding: 0;
}
.tdbmd-mesh__list .tdbmd-mesh__list-btn {
    color: var(--text-default-grey);
}
.tdbmd-mesh__list .tdbmd-mesh__list-btn--current {
    color: var(--text-action-high-blue-france);
}
.tdbmd-mesh .tdbmd-mesh__btn {
    width: 100%;
    text-align: left;
    display: inline-block;
    border-bottom: 3px solid var(--text-action-high-blue-france);
    position: relative;
    background: white;
}
.tdbmd-mesh .tdbmd-mesh__btn:after {
    position: absolute;
    top: 50%;
    right: 1rem;
    transform: translateY(-50%);
}
.tdbmd-mesh .tdbmd-mesh__btn-title {
    display: block;
    color: var(--text-mention-grey);
}
.tdbmd-mesh .tdbmd-mesh__btn-mesh {
    display: block;
}
.tdbmd-mesh .tdbmd-mesh__list-btn {
    width: 100%;
    padding: 0 1rem;
    padding-right: 2.5rem;
}
.tdbmd-indicator-card {
    background: var(--grey-1000-50);
    border: 1px solid var(--border-default-grey);
    border-bottom: none;
    box-shadow: none;
}
.tdbmd-indicator-card__data-container {
    color: var(--text-action-high-blue-france);
}
.tdbmd-indicator-card__data-number {
    font-size: 30px;
    line-height: 1.2;
    font-weight: 700;
}
.tdbmd-indicator-card__comparisons-card {
    border: 1px solid var(--border-default-grey);
    border-left: 3px solid var(--background-action-high-blue-france);
    color: var(--text-action-high-blue-france);
    text-align: center;
    height: 100%;
}
.tdbmd-indicator-card__comparisons-card--average {
    border-left-color: var(--background-action-high-blue-france);
}
.tdbmd-indicator-card__comparisons-card-title {
    font-weight: 700;
    margin-bottom: 1rem;
    font-size: 1.2rem;
}
.tdbmd-indicator-card__comparisons-card-number {
    font-size: 1.5rem;
    margin-bottom: 1rem;
}
.tdbmd-indicator-card__comparisons-card-info {
    margin-bottom: 1rem;
}
.tdbmd-indicator-card__comparisons-card-info span {
    display: block;
}
.tdbmd-indicator-card__comparisons-card-info {
    cursor: pointer;
}
.tdbmd-indicator-card__comparisons-col {
    min-width: 150px;
}
.fr-tag-list .fr-tag {
    margin: 0 0.25rem 0.5rem;
    vertical-align: top;
}
.tdbmd-indicator-accordion {
    background: var(--grey-1000-100);
    border-left: 1px solid var(--border-default-grey);
    border-right: 1px solid var(--border-default-grey);
}
.tdbmd-indicator-accordion-comparison {
    border-bottom: 1px solid var(--border-default-grey);
}
.tdbmd-indicator-accordion::before {
    box-shadow: none;
}
.fr-btn.tdbmd-indicator-btn {
    background: var(--grey-1000-100);
    border: 1px solid var(--border-default-grey);
    box-shadow: none;
    width: 100%;
    display: inline-flex;
    font-size: 1rem;
    line-height: 1.5rem;
    min-height: 3rem;
    position: relative;
}
.fr-btn.tdbmd-indicator-btn:after {
    right: 1rem;
    position: absolute;
}
.tdbmd-indicator-source {
    font-style: italic;
}
.tdbmd-indicator-source__title {
    text-decoration: underline;
}
.rdt_Table,
.rdt_TableRow,
.rdt_TableCol,
.rdt_TableCol_Sortable,
.rdt_TableCell,
.rdt_TableHeader,
.rdt_TableFooter,
.rdt_TableHead,
.rdt_TableHeadRow,
.rdt_TableBody,
.rdt_ExpanderRow {
    background-color: transparent;
}
.rdt_TableCol_Sortable span {
    opacity: 0.8;
}
.rdt_TableCol_Sortable span:hover {
    color: var(--text-action-high-blue-france);
}
#tdbmd-map {
    width: 100%;
    height: 60vh;
    position: relative;
    border: 1px solid var(--border-default-grey);
}
#tdbmd-map[fullscreen] {
    width: calc(100vw - 4rem);
    height: 90vh;
}
#tdbmd-map-legend {
    position: absolute;
    bottom: 10px;
    left: 10px;
    padding: 8px 16px 0px 16px;
    max-width: 300px;
    min-width: 200px;
    background-color: white;
    border-radius: 8px;
    opacity: 94%;
}
#tdbmd-map-legend .title {
    margin-bottom: 8px;
    font-size: 0.7rem;
    font-weight: bold;
    line-height: 1.3;
}
#tdbmd-map-legend .indicator-scale {
    width: 100%;
    height: 20px;
    opacity: 80%;
}
#tdbmd-map-legend .indicator-scale-values {
    width: 100%;
    display: flex;
    justify-content: space-between;
    gap: 8px;
}
#tdbmd-map-legend .scale-minmax {
    max-width: 100px;
    text-overflow: ellipsis;
    overflow: hidden;
    white-space: nowrap;
    font-size: 0.7rem;
}
#map-sidebar {
    position: absolute;
    z-index: 2;
    right: -1px;
    width: 300px;
    height: 100%;
    transition: width ease-in-out 0.3s;
    border-left: 1px solid var(--border-default-grey);
    border-right: 1px solid var(--border-default-grey);
    background-color: white;
    opacity: 94%;
}
#map-sidebar .ms-container {
    width: 100%;
    height: 100%;
    overflow-x: hidden;
    overflow-y: scroll;
}
#map-sidebar .ms-body {
    width: 300px;
    height: 100%;
    padding: 16px;
    display: flex;
    flex-direction: column;
    gap: 32px;
}
#map-sidebar .sidebar-title {
    font-size: 1.2rem;
    font-weight: bold;
}
#map-sidebar .title {
    margin-bottom: 16px;
    font-size: 1rem;
    font-weight: bold;
}
#map-sidebar .territory-name {
    font-size: 0.8rem;
    font-style: italic;
}
#map-sidebar #collapse {
    position: absolute;
    left: -40px;
    top: 16px;
    width: 40px;
    height: 40px;
    background-color: white;
    color: var(--text-action-high-blue-france);
    border: 1px solid var(--border-default-grey);
    cursor: pointer;
}
#map-sidebar #collapse span:before {
    transform: scaleX(-1);
}
#map-sidebar #collapse:hover {
    background-color: var(--grey-1000-50-hover);
}
#map-sidebar #collapse:focus {
    outline-offset: 2px;
    outline: 2px solid #fcc63a;
    background-color: #fef5e8;
    border: 1px dashed gray;
}
#map-sidebar .loader {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 16px;
}
#map-sidebar .spinner {
    color: #465f9d;
    animation: spin 1s linear infinite;
}
#map-sidebar .spinner circle {
    stroke-dasharray: 100;
    stroke-dashoffset: 0;
}
@keyframes spin {
    100% {
        transform: rotate(360deg);
    }
}
#map-sidebar .geo-feature-count {
    display: flex;
    gap: 8px;
    align-items: center;
}
#map-sidebar .filterTitle {
    font-size: 13px;
    padding-left: 14px;
    margin-top: 4px;
    margin-bottom: 16px;
}
#map-sidebar[data-open="false"] {
    width: 32px;
}
#map-sidebar[data-open="false"] #collapse span:before {
    transform: scaleX(1);
}
#map-buttons {
    position: absolute;
    z-index: 1;
    top: 8px;
    left: 8px;
    display: flex;
    flex-direction: column;
    gap: 8px;
}
#map-buttons .map-button {
    border: 1px solid var(--border-default-grey);
    background-color: white;
    color: var(--text-action-high-blue-france);
    opacity: 94%;
    width: 32px;
    height: 32px;
    cursor: pointer;
    display: flex;
    justify-content: center;
    align-items: center;
}
#map-buttons .map-button:hover {
    background-color: var(--grey-1000-50-hover);
}
#map-buttons .map-button:focus {
    outline-offset: 2px;
    outline: 2px solid #fcc63a;
    background-color: #fef5e8;
    border: 1px dashed gray;
}
#left-menu[hide] {
    display: none;
}
.tdbmd-slide-panel-fiche-methodo {
    overflow-y: scroll;
    height: 100vh;
}
.tdbmd-slide-panel-fiche-methodo h3 {
    color: var(--text-default-grey);
    font-size: 1.2rem;
}
.tdbmd-slide-panel-fiche-methodo .tdbmd-markdown h3 {
    font-size: 1.4rem;
}
.tdbmd-slide-panel-fiche-methodo .tdbmd-markdown .tdbmd-slide-panel__subtitle {
    margin-left: 0;
}
.tdbmd-territory .tdbmd-territory__btn {
    width: 100%;
    text-align: left;
    display: inline-block;
    border-bottom: 3px solid var(--text-action-high-blue-france);
    position: relative;
    background: white;
    padding-right: 2.5rem;
}
.tdbmd-territory .tdbmd-territory__btn:after {
    position: absolute;
    top: 50%;
    right: 1rem;
    transform: translateY(-50%);
}
.tdbmd-territory .tdbmd-territory__btn-title {
    display: block;
    color: var(--text-mention-grey);
    white-space: nowrap;
}
.tdbmd-territory .tdbmd-territory__btn-mesh {
    display: block;
    white-space: nowrap;
}
#sankey-tooltip {
    position: fixed;
    background: rgba(0, 0, 0, 0.8);
    color: white;
    padding: 8px;
    border-radius: 4px;
    pointer-events: none;
    font-size: 12px;
}
.tdbmd-slide-panel {
    display: none;
    position: fixed;
    width: 100vw;
    top: 0;
    right: 0;
    transform: translateX(110%);
    z-index: 1000;
    box-sizing: border-box;
    transition: transform ease-in-out 0.3s;
}
.tdbmd-slide-panel.tdbmd-slide-panel--show {
    transform: initial;
}
@media (min-width: 992px) {
    .tdbmd-slide-panel {
        width: 60vw;
        right: 0;
        left: initial;
    }
    .tdbmd-slide-panel__btn {
        display: block !important;
        position: absolute;
        left: 0;
        transform: translateX(calc(-50% + 0.5rem));
    }
    .tdbmd-slide-panel__btn--mobile {
        display: none !important;
    }
    .tdbmd-slide-panel__content {
        margin-left: 2rem;
        border: 1px solid var(--border-default-grey);
    }
}
@media (min-width: 1248px) {
    .tdbmd-slide-panel {
        width: 50vw;
    }
}
.tdbmd-slide-panel__content {
    height: 100vh;
    background: white;
    overflow: scroll;
    /* Hide scrollbar for Chrome, Safari and Opera */
    /* Hide scrollbar for IE, Edge and Firefox */
    -ms-overflow-style: none;
    /* IE and Edge */
    scrollbar-width: none;
    /* Firefox */
}
.tdbmd-slide-panel__content::-webkit-scrollbar {
    display: none;
}
.tdbmd-slide-panel .fr-accordion,
.tdbmd-slide-panel h2,
.tdbmd-slide-panel p,
.tdbmd-slide-panel ul {
    margin-left: 2rem;
    margin-right: 2rem;
}
.tdbmd-slide-panel .tdbmd-slide-panel__title {
    color: var(--text-action-high-blue-france);
    padding-top: 1rem !important;
}
.tdbmd-slide-panel__theme-list {
    padding: 0;
}
.tdbmd-slide-panel__theme-list-item {
    list-style-type: none;
    display: inline-block;
}
.tdbmd-slide-panel__theme-list-item:not(:first-child):before {
    content: "\0000A0>\000020";
}
.tdbmd-slide-panel__subtitle {
    background: var(--background-action-high-blue-france);
    color: white !important;
    padding: 0.5rem 2rem;
    margin-top: 2rem !important;
    margin-bottom: 2rem !important;
}
.tdbmd-slide-panel__thematic {
    margin-left: 0px !important;
}
.tdbmd-slide-panel__btn.fr-btn.fr-btn--tertiary {
    display: none;
    box-sizing: border-box;
    padding: 0 0.8rem 0.4rem;
    border: none;
    background: white;
    color: var(--text-action-high-blue-france);
}
.tdbmd-slide-panel__btn--mobile {
    display: block;
}
.tdbmd-slide-panel__icon:before {
    transform: scaleX(-1);
}
#superset-container iframe {
    height: calc(100vh - 75px);
    width: 100vw;
}
.fr-sidemenu {
    margin: 0;
}

.tdbmd-table-container {
    max-width: 900px;
}

.tdbmd-table {
    width: 100%;
    border-collapse: collapse;
    border: 1px solid #929292;
    text-align: left;
}

.tdbmd-table th,
.tdbmd-table td {
    padding: 8px 16px;
    border: 1px solid #929292;
}

.tdbmd-table th {
    background-color: #f6f6f6;
    cursor: pointer;
    justify-content: center;
}

.tdbmd-table td {
    background-color: white;
    font-size: smaller;
}

.orderableTh > div:first-child {
    display: flex;
    justify-content: center;
    align-items: center;
    gap: 4px;
}

.tdbmd-table th .orderArrow {
    font-size: 14px;
}

.tdbmd-table th .orderArrow.orderArrowBoth {
    font-size: 20px;
    padding-bottom: 4px;
}

.tdbmd-table tbody > tr:focus > td {
    background-color: #ececfe;
}

.fr-pagination__link.fr-pagination__link-override {
    margin-left: 0.2rem;
    margin-right: 0.2rem;
}

.fr-pagination__link.fr-pagination__link-override:hover {
    margin-left: 0.2rem;
    margin-right: 0.2rem;
    background-color: #f6f6f6;
}

.tdbmd-table th[data-name="annee"] {
    width: 64px;
}

.tdbmd-table th[data-name="lieu"] {
    width: 35%;
}

.tdbmd-table-header {
    width: 100%;
    display: flex;
    justify-content: end;
    margin-bottom: 1rem;
}
.delay-spinner {
    opacity: 0%;
}
#thematics-links {
    margin-top: 2rem;
    line-height: 2rem;
    list-style: none;
}
@media (min-width: 768px) {
    #thematics-links {
        display: none;
    }
}
@media (max-width: 768px) {
    .journal tr {
        display: flex;
        flex-direction: column;
    }
}
.title-tooltip {
    display: flex;
    align-items: center;
}

.title-tooltip > div:last-child {
    padding: 8px;
}
.chart-buttons {
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
    align-items: center;
    gap: 2rem;
    padding: 2rem;
}

.chart-buttons label::before {
    margin-right: 0.5rem;
}

.comparison-main-values {
    display: flex;
    flex-direction: row;
    gap: 32px;
    flex-wrap: wrap;
    align-items: baseline;
}
.border-top {
    border-top: 1px solid var(--border-default-grey);
}

.filters-dimension {
    display: flex;
    flex-direction: column;
}

.filters-dimension:not(:last-child) {
    margin-bottom: 16px;
}

.filters-dimension > label {
    margin-bottom: 4px;
    font-style: italic;
    font-size: smaller;
}

.filters-reminder {
    margin-top: 16px;
}

.filters-reminder label {
    font-style: italic;
    font-size: smaller;
    margin-right: 8px;
}

.filters-reminder a {
    margin-left: 8px;
}

.filters-reminder-dimension > p:not(:first-child) {
    margin-left: 4px;
}

footer .fr-follow {
    border-top: 1px solid var(--border-default-grey);
}

.fr-notice__link {
    text-decoration: underline;
}

.fr-notice[data-show="false"] {
    display: none;
}

.fr-notice[data-show="true"] {
    display: block;
}

#header-navigation > div:first-child {
    position: relative;
}
.mapboxgl-ctrl-logo {
    display: none !important;
}
#deckgl-wrapper:focus {
    outline: 2px solid #0a76f6 !important;
}
.internal-outline:focus {
    outline-offset: -2px;
}
.fr-header__logo:hover {
    background-color: var(--grey-1000-50-hover);
}
@media (max-width: 991px) {
    .fr-nav__btn[aria-current]:not([aria-current="false"]),
    .fr-nav__link[aria-current]:not([aria-current="false"]) {
        text-decoration: underline;
    }
}

.data-table {
    overflow-x: auto;
}
.data-table-export-buttons {
    margin-bottom: 16px;
    margin-top: 16px;
    display: flex;
    gap: 16px;
    flex-wrap: wrap;
}
.checkbox-label {
    text-wrap: nowrap;
}
#map-download-buttons {
    margin-top: 32px;
    display: flex;
    flex-wrap: wrap;
    gap: 16px;
}
.side-panel-last-close-button-container {
    display: flex;
    justify-content: end;
    margin-top: 32px;
    margin-right: 4px;
}
.search-bar-sm input {
    padding: 0px 8px;
}

.search-bar-sm button {
    width: 24px;
    padding: 0px 8px !important;
}

.table-geo-filters {
    margin-top: 16px;
    display: flex;
    flex-direction: column;
    gap: 8px;
    padding-bottom: 64px;
}

.table-geo-filters {
    font-size: 0.9rem;
}

.table-geo-filters:has(details[open]) {
    padding-bottom: 300px;
}

.table-geo-filters input,
.table-geo-filters select {
    padding: 4px 8px;
    max-width: 250px;
    margin-top: 0px !important;
}

.table-geo-filters input[type="number"] {
    max-width: 70px;
}

.table-geo-filters label,
.table-geo-filters i {
    font-size: 0.8rem;
}

.table-geo-filters-details-body {
    margin-top: 8px;
    margin-bottom: 8px;
}

.geo-filters-numbers-col {
    display: flex;
    flex-direction: column;
    gap: 8px;
}

.geo-filters-numbers-row {
    display: flex;
    flex-direction: row;
    gap: 32px;
}

.staticPage .code {
    background-color: #ececfe;
    font-family: inherit;
    padding: 0 4px;
    border-radius: 4px;
    font-size: smaller;
    font-style: normal;
}

.staticPage table {
    width: 100%;
    border-collapse: collapse;
}

.staticPage table th,
.staticPage table td {
    padding: 8px 16px;
    text-align: left;
}

.staticPage caption {
    font-weight: bold;
    text-align: left;
    margin-bottom: 16px;
}

.staticPage tbody td:first-child {
    font-weight: bold;
}

.glossary .definitions {
    margin-top: 6rem;
    display: flex;
    flex-direction: column;
    gap: 2rem;
}
.glossary .definitions div {
    display: flex;
    align-items: center;
}
.glossary .definitions dt {
    width: 10rem;
}
.glossary .definitions dd {
    width: 100%;
}

@media (min-width: 48em) {
    .fr-footer__bottom-item::before {
        margin-right: 0.5rem;
    }
}

.fr-footer__bottom-link {
    white-space: nowrap;
}

.react-datepicker__input-container input {
    border-color: hsl(0, 0%, 80%);
    border-radius: 4px;
    border-style: solid;
    border-width: 1px;
    width: 95px;
}

.date-pickers-range {
    display: flex;
    flex-direction: row;
    gap: 32px;
}

.react-datepicker__header {
    background-color: #ececfe !important;
}

.react-datepicker__header h2 {
    padding: 0px !important;
}

.react-datepicker__header__dropdown {
    padding-bottom: 16px !important;
}

.react-datepicker__close-icon:hover {
    background-color: inherit !important;
}

.react-select__menu {
    font-size: 0.8rem !important;
}

.react-select__option {
    padding: 4px 12px !important;
}
